@@ -1,5 +1,5 @@
 /* Groundhog -- a simple logic game
- * Copyright (C) 1999-2001 Maurits Rijk
+ * Copyright (C) 1999-2002 Maurits Rijk
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ protected:
 public:
    Dialog(const char* title);
    virtual ~Dialog() {}
-   virtual void DoDialog() {gtk_widget_show(_window);}
+   virtual void DoDialog();
 };
 
 #endif // _DIALOG_H
