@@ -1,5 +1,5 @@
 /* Groundhog -- a simple logic game
- * Copyright (C) 1998-2001 Maurits Rijk
+ * Copyright (C) 1998-2002 Maurits Rijk
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ class NewGameDialog : public Dialog {
    GtkWidget* 	_rows;
    GtkWidget*	_columns;
 
-   void SetRowColumns(gint sensitive);
+   void SetRowColumns(gboolean sensitive);
    static void UserDefinableCB(GtkWidget *widget, gpointer data);
 protected:
    Game*	_game;
