@@ -1,5 +1,5 @@
 /* Groundhog -- a simple logic game
- * Copyright (C) 1998-2001 Maurits Rijk
+ * Copyright (C) 1998-2002 Maurits Rijk
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,18 +20,16 @@
 #include "intl.h"
 #include "options_dialog.h"
 
-OptionsDialog::OptionsDialog(Game* game) : Dialog(_("Options")), _game(game)
+OptionsDialog::OptionsDialog(Game* game) : Dialog(_("Preferences")), 
+					   _game(game)
 {
-   SetSize(150, 120);
-
    GtkWidget* box = gtk_hbox_new(FALSE, 1);;
    gtk_container_border_width(GTK_CONTAINER(box), 10);
    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(_window)->vbox), box, TRUE, TRUE, 10);
-   _tooltips = gtk_check_button_new_with_label(_("Show Tooltips"));
+   _tooltips = gtk_check_button_new_with_mnemonic(_("_Show Tooltips"));
    gtk_container_add(GTK_CONTAINER(box), _tooltips);
    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(_tooltips), TRUE);
-   gtk_widget_show(_tooltips);
-   gtk_widget_show(box);
+
    AddCancelButton();
 }
 
